==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AShlBinop.h <==
// public final class soot.jimple.parser.node.AShlBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 250edee817a4a5b6 soot_jimple_parser_node_AShlBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AShlBinop_H_
#define _JC_soot_jimple_parser_node_AShlBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TShl$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AShlBinop$sub_refs	_jc_soot_jimple_parser_node_AShlBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AShlBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AShlBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShlBinop$refs	_jc_soot_jimple_parser_node_AShlBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AShlBinop$nonrefs	_jc_soot_jimple_parser_node_AShlBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShlBinop$object	_jc_soot_jimple_parser_node_AShlBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AShlBinop$vmethods	_jc_soot_jimple_parser_node_AShlBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AShlBinop$vtable	_jc_soot_jimple_parser_node_AShlBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AShlBinop$vtype	_jc_soot_jimple_parser_node_AShlBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AShlBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *);
extern void _jc_soot_jimple_parser_node_AShlBinop$method$_init$6b84dd6dd80393a2(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_TShl$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AShlBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AShlBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *);
extern struct _jc_soot_jimple_parser_node_TShl$object *_jc_soot_jimple_parser_node_AShlBinop$method$getShl$68c60cb8bf6a8759(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *);
extern void _jc_soot_jimple_parser_node_AShlBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AShlBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AShlBinop$method$setShl$a0ef02093f641fab(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_TShl$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AShlBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$getShl$68c60cb8bf6a8759;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$setShl$a0ef02093f641fab;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AShlBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *);
	struct _jc_soot_jimple_parser_node_TShl$object	*(*getShl$68c60cb8bf6a8759)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setShl$a0ef02093f641fab)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_TShl$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AShlBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AShlBinop$vmethods	soot_jimple_parser_node_AShlBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AShlBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AShlBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShlBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TShl$object	*__5fshl__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShlBinop$refs {
    _jc_soot_jimple_parser_node_AShlBinop$sub_refs	soot_jimple_parser_node_AShlBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShlBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShlBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AShlBinop$sub_nonrefs	soot_jimple_parser_node_AShlBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AShlBinop$object {
	_jc_soot_jimple_parser_node_AShlBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AShlBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AShlBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AShlBinop$vtype _jc_soot_jimple_parser_node_AShlBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AShlBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AShlBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AShlBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AShlBinop.h <==
// public final class soot.jimple.parser.node.AShlBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 250edee817a4a5b6 soot_jimple_parser_node_AShlBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AShlBinop_H_
#define _JC_soot_jimple_parser_node_AShlBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TShl$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AShlBinop$sub_refs	_jc_soot_jimple_parser_node_AShlBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AShlBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AShlBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShlBinop$refs	_jc_soot_jimple_parser_node_AShlBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AShlBinop$nonrefs	_jc_soot_jimple_parser_node_AShlBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShlBinop$object	_jc_soot_jimple_parser_node_AShlBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AShlBinop$vmethods	_jc_soot_jimple_parser_node_AShlBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AShlBinop$vtable	_jc_soot_jimple_parser_node_AShlBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AShlBinop$vtype	_jc_soot_jimple_parser_node_AShlBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AShlBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShlBinop$method$_init$6b84dd6dd80393a2(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_TShl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AShlBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AShlBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TShl$object *_jc_soot_jimple_parser_node_AShlBinop$method$getShl$68c60cb8bf6a8759(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShlBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShlBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShlBinop$method$setShl$a0ef02093f641fab(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_TShl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AShlBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$getShl$68c60cb8bf6a8759;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$setShl$a0ef02093f641fab;
extern _jc_method _jc_soot_jimple_parser_node_AShlBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AShlBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TShl$object	*(*getShl$68c60cb8bf6a8759)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setShl$a0ef02093f641fab)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *, struct _jc_soot_jimple_parser_node_TShl$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AShlBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AShlBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AShlBinop$vmethods	soot_jimple_parser_node_AShlBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AShlBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AShlBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShlBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TShl$object	*__5fshl__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShlBinop$refs {
    _jc_soot_jimple_parser_node_AShlBinop$sub_refs	soot_jimple_parser_node_AShlBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShlBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShlBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AShlBinop$sub_nonrefs	soot_jimple_parser_node_AShlBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AShlBinop$object {
	_jc_soot_jimple_parser_node_AShlBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AShlBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AShlBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AShlBinop$vtype _jc_soot_jimple_parser_node_AShlBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AShlBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AShlBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AShlBinop_H_ */
